.. webapi-error::
   :title: Commit ID Already Exists
   :instance: reviewboard.webapi.errors.COMMIT_ID_ALREADY_EXISTS

   An attempt was made to create a review request, but a request with
   that commit ID already exists in the repository.
